"""
Pydantic models for confluence connector.

This module contains Pydantic models used for authentication configuration
and response envelope types.
"""

from __future__ import annotations

from pydantic import BaseModel, ConfigDict, Field
from typing import TypeVar, Generic, Union, Any

# Authentication configuration

class ConfluenceAuthConfig(BaseModel):
    """Confluence API Token Authentication - Authenticate using your Atlassian account email and API token"""

    model_config = ConfigDict(extra="forbid")

    username: str
    """Your Atlassian account email address"""
    password: str
    """Your Confluence API token from https://id.atlassian.com/manage-profile/security/api-tokens"""

# ===== RESPONSE TYPE DEFINITIONS (PYDANTIC) =====

class SpaceLinks(BaseModel):
    """Links related to the space"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    webui: Union[str, Any] = Field(default=None, description="Web UI link")
    """Web UI link"""
    base: Union[str, Any] = Field(default=None, description="Base URL")
    """Base URL"""

class Space(BaseModel):
    """Confluence space object"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    id: Union[str, Any] = Field(default=None)
    key: Union[str, Any] = Field(default=None)
    name: Union[str, Any] = Field(default=None)
    type_: Union[str, Any] = Field(default=None, alias="type")
    status: Union[str, Any] = Field(default=None)
    author_id: Union[str, Any] = Field(default=None, alias="authorId")
    created_at: Union[str, Any] = Field(default=None, alias="createdAt")
    homepage_id: Union[str, Any] = Field(default=None, alias="homepageId")
    space_owner_id: Union[str, Any] = Field(default=None, alias="spaceOwnerId")
    current_active_alias: Union[str, Any] = Field(default=None, alias="currentActiveAlias")
    description: Union[Any, Any] = Field(default=None)
    icon: Union[Any, Any] = Field(default=None)
    links: Union[SpaceLinks, Any] = Field(default=None, alias="_links")

class SpacesListLinks(BaseModel):
    """Nested schema for SpacesList._links"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    next: Union[str, Any] = Field(default=None, description="URL for the next page of results")
    """URL for the next page of results"""
    base: Union[str, Any] = Field(default=None, description="Base URL")
    """Base URL"""

class SpacesList(BaseModel):
    """Paginated list of spaces"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    results: Union[list[Space], Any] = Field(default=None)
    links: Union[SpacesListLinks, Any] = Field(default=None, alias="_links")

class PageBody(BaseModel):
    """Page body content"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    storage: Union[dict[str, Any], Any] = Field(default=None, description="Storage format body")
    """Storage format body"""
    atlas_doc_format: Union[dict[str, Any], Any] = Field(default=None, description="Atlas doc format body")
    """Atlas doc format body"""

class PageVersion(BaseModel):
    """Version information"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    created_at: Union[str, Any] = Field(default=None, alias="createdAt", description="Version creation timestamp")
    """Version creation timestamp"""
    message: Union[str, Any] = Field(default=None, description="Version message")
    """Version message"""
    number: Union[int, Any] = Field(default=None, description="Version number")
    """Version number"""
    minor_edit: Union[bool, Any] = Field(default=None, alias="minorEdit", description="Whether this was a minor edit")
    """Whether this was a minor edit"""
    author_id: Union[str, Any] = Field(default=None, alias="authorId", description="ID of the version author")
    """ID of the version author"""
    ncs_step_version: Union[Any, Any] = Field(default=None, alias="ncsStepVersion", description="NCS step version")
    """NCS step version"""

class PageLinks(BaseModel):
    """Links related to the page"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    webui: Union[str, Any] = Field(default=None, description="Web UI link")
    """Web UI link"""
    editui: Union[str, Any] = Field(default=None, description="Edit UI link")
    """Edit UI link"""
    edituiv2: Union[str, Any] = Field(default=None, description="Edit UI v2 link")
    """Edit UI v2 link"""
    tinyui: Union[str, Any] = Field(default=None, description="Tiny UI link")
    """Tiny UI link"""
    base: Union[str, Any] = Field(default=None, description="Base URL")
    """Base URL"""

class Page(BaseModel):
    """Confluence page object"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    id: Union[str, Any] = Field(default=None)
    status: Union[str, Any] = Field(default=None)
    title: Union[str, Any] = Field(default=None)
    space_id: Union[str, Any] = Field(default=None, alias="spaceId")
    parent_id: Union[Any, Any] = Field(default=None, alias="parentId")
    parent_type: Union[Any, Any] = Field(default=None, alias="parentType")
    position: Union[int, Any] = Field(default=None)
    author_id: Union[str, Any] = Field(default=None, alias="authorId")
    owner_id: Union[str, Any] = Field(default=None, alias="ownerId")
    last_owner_id: Union[Any, Any] = Field(default=None, alias="lastOwnerId")
    created_at: Union[str, Any] = Field(default=None, alias="createdAt")
    version: Union[PageVersion, Any] = Field(default=None)
    body: Union[PageBody, Any] = Field(default=None)
    links: Union[PageLinks, Any] = Field(default=None, alias="_links")

class PagesListLinks(BaseModel):
    """Nested schema for PagesList._links"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    next: Union[str, Any] = Field(default=None, description="URL for the next page of results")
    """URL for the next page of results"""
    base: Union[str, Any] = Field(default=None, description="Base URL")
    """Base URL"""

class PagesList(BaseModel):
    """Paginated list of pages"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    results: Union[list[Page], Any] = Field(default=None)
    links: Union[PagesListLinks, Any] = Field(default=None, alias="_links")

class BlogPostLinks(BaseModel):
    """Links related to the blog post"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    webui: Union[str, Any] = Field(default=None, description="Web UI link")
    """Web UI link"""
    editui: Union[str, Any] = Field(default=None, description="Edit UI link")
    """Edit UI link"""
    edituiv2: Union[str, Any] = Field(default=None, description="Edit UI v2 link")
    """Edit UI v2 link"""
    tinyui: Union[str, Any] = Field(default=None, description="Tiny UI link")
    """Tiny UI link"""
    base: Union[str, Any] = Field(default=None, description="Base URL")
    """Base URL"""

class BlogPostVersion(BaseModel):
    """Version information"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    created_at: Union[str, Any] = Field(default=None, alias="createdAt", description="Version creation timestamp")
    """Version creation timestamp"""
    message: Union[str, Any] = Field(default=None, description="Version message")
    """Version message"""
    number: Union[int, Any] = Field(default=None, description="Version number")
    """Version number"""
    minor_edit: Union[bool, Any] = Field(default=None, alias="minorEdit", description="Whether this was a minor edit")
    """Whether this was a minor edit"""
    author_id: Union[str, Any] = Field(default=None, alias="authorId", description="ID of the version author")
    """ID of the version author"""
    ncs_step_version: Union[Any, Any] = Field(default=None, alias="ncsStepVersion", description="NCS step version")
    """NCS step version"""

class BlogPostBody(BaseModel):
    """Blog post body content"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    storage: Union[dict[str, Any], Any] = Field(default=None, description="Storage format body")
    """Storage format body"""
    atlas_doc_format: Union[dict[str, Any], Any] = Field(default=None, description="Atlas doc format body")
    """Atlas doc format body"""

class BlogPost(BaseModel):
    """Confluence blog post object"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    id: Union[str, Any] = Field(default=None)
    status: Union[str, Any] = Field(default=None)
    title: Union[str, Any] = Field(default=None)
    space_id: Union[str, Any] = Field(default=None, alias="spaceId")
    author_id: Union[str, Any] = Field(default=None, alias="authorId")
    created_at: Union[str, Any] = Field(default=None, alias="createdAt")
    version: Union[BlogPostVersion, Any] = Field(default=None)
    body: Union[BlogPostBody, Any] = Field(default=None)
    links: Union[BlogPostLinks, Any] = Field(default=None, alias="_links")

class BlogPostsListLinks(BaseModel):
    """Nested schema for BlogPostsList._links"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    next: Union[str, Any] = Field(default=None, description="URL for the next page of results")
    """URL for the next page of results"""
    base: Union[str, Any] = Field(default=None, description="Base URL")
    """Base URL"""

class BlogPostsList(BaseModel):
    """Paginated list of blog posts"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    results: Union[list[BlogPost], Any] = Field(default=None)
    links: Union[BlogPostsListLinks, Any] = Field(default=None, alias="_links")

class GroupLinks(BaseModel):
    """Links related to the group"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    self: Union[str, Any] = Field(default=None, description="Self link")
    """Self link"""

class Group(BaseModel):
    """Confluence group object"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    type_: Union[str, Any] = Field(default=None, alias="type")
    id: Union[str, Any] = Field(default=None)
    name: Union[str, Any] = Field(default=None)
    managed_by: Union[str, Any] = Field(default=None, alias="managedBy")
    usage_type: Union[str, Any] = Field(default=None, alias="usageType")
    resource_ari: Union[str, Any] = Field(default=None, alias="resourceAri")
    links: Union[GroupLinks, Any] = Field(default=None, alias="_links")

class GroupsListLinks(BaseModel):
    """Nested schema for GroupsList._links"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    base: Union[str, Any] = Field(default=None)
    context: Union[str, Any] = Field(default=None)
    next: Union[str, Any] = Field(default=None)
    self: Union[str, Any] = Field(default=None)

class GroupsList(BaseModel):
    """Paginated list of groups"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    results: Union[list[Group], Any] = Field(default=None)
    start: Union[int, Any] = Field(default=None)
    limit: Union[int, Any] = Field(default=None)
    size: Union[int, Any] = Field(default=None)
    links: Union[GroupsListLinks, Any] = Field(default=None, alias="_links")

class AuditRecordAffectedobject(BaseModel):
    """Object affected by the audit event"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    name: Union[str, Any] = Field(default=None, description="Name of the affected object")
    """Name of the affected object"""
    object_type: Union[str, Any] = Field(default=None, alias="objectType", description="Type of the affected object")
    """Type of the affected object"""

class AuditRecordAssociatedobjectsItem(BaseModel):
    """Nested schema for AuditRecord.associatedObjects_item"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    name: Union[str, Any] = Field(default=None, description="Name of the associated object")
    """Name of the associated object"""
    object_type: Union[str, Any] = Field(default=None, alias="objectType", description="Type of the associated object")
    """Type of the associated object"""

class AuditRecordAuthor(BaseModel):
    """User who triggered the audit event"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    type_: Union[str, Any] = Field(default=None, alias="type", description="Author type")
    """Author type"""
    display_name: Union[str, Any] = Field(default=None, alias="displayName", description="Display name of the author")
    """Display name of the author"""
    public_name: Union[str, Any] = Field(default=None, alias="publicName", description="Public name of the author")
    """Public name of the author"""
    account_type: Union[str, Any] = Field(default=None, alias="accountType", description="Account type")
    """Account type"""
    is_external_collaborator: Union[bool, Any] = Field(default=None, alias="isExternalCollaborator", description="Whether the author is an external collaborator")
    """Whether the author is an external collaborator"""
    external_collaborator: Union[bool, Any] = Field(default=None, alias="externalCollaborator", description="Whether the author is an external collaborator")
    """Whether the author is an external collaborator"""
    operations: Union[Any, Any] = Field(default=None, description="Operations available for the author")
    """Operations available for the author"""

class AuditRecord(BaseModel):
    """Confluence audit record"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    author: Union[AuditRecordAuthor, Any] = Field(default=None)
    remote_address: Union[str, Any] = Field(default=None, alias="remoteAddress")
    creation_date: Union[int, Any] = Field(default=None, alias="creationDate")
    summary: Union[str, Any] = Field(default=None)
    description: Union[str, Any] = Field(default=None)
    category: Union[str, Any] = Field(default=None)
    sys_admin: Union[bool, Any] = Field(default=None, alias="sysAdmin")
    super_admin: Union[bool, Any] = Field(default=None, alias="superAdmin")
    affected_object: Union[AuditRecordAffectedobject, Any] = Field(default=None, alias="affectedObject")
    changed_values: Union[list[Any], Any] = Field(default=None, alias="changedValues")
    associated_objects: Union[list[AuditRecordAssociatedobjectsItem], Any] = Field(default=None, alias="associatedObjects")

class AuditRecordsListLinks(BaseModel):
    """Nested schema for AuditRecordsList._links"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    base: Union[str, Any] = Field(default=None)
    context: Union[str, Any] = Field(default=None)
    next: Union[str, Any] = Field(default=None)
    self: Union[str, Any] = Field(default=None)

class AuditRecordsList(BaseModel):
    """Paginated list of audit records"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    results: Union[list[AuditRecord], Any] = Field(default=None)
    start: Union[int, Any] = Field(default=None)
    limit: Union[int, Any] = Field(default=None)
    size: Union[int, Any] = Field(default=None)
    links: Union[AuditRecordsListLinks, Any] = Field(default=None, alias="_links")

# ===== METADATA TYPE DEFINITIONS (PYDANTIC) =====
# Meta types for operations that extract metadata (e.g., pagination info)

class SpacesListResultMeta(BaseModel):
    """Metadata for spaces.Action.LIST operation"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    next: Union[str, Any] = Field(default=None)

class PagesListResultMeta(BaseModel):
    """Metadata for pages.Action.LIST operation"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    next: Union[str, Any] = Field(default=None)

class BlogPostsListResultMeta(BaseModel):
    """Metadata for blog_posts.Action.LIST operation"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    next: Union[str, Any] = Field(default=None)

class GroupsListResultMeta(BaseModel):
    """Metadata for groups.Action.LIST operation"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    start: Union[int, Any] = Field(default=None)
    limit: Union[int, Any] = Field(default=None)
    size: Union[int, Any] = Field(default=None)

class AuditListResultMeta(BaseModel):
    """Metadata for audit.Action.LIST operation"""
    model_config = ConfigDict(extra="allow", populate_by_name=True)

    start: Union[int, Any] = Field(default=None)
    limit: Union[int, Any] = Field(default=None)
    size: Union[int, Any] = Field(default=None)

# ===== CHECK RESULT MODEL =====

class ConfluenceCheckResult(BaseModel):
    """Result of a health check operation.

    Returned by the check() method to indicate connectivity and credential status.
    """
    model_config = ConfigDict(extra="forbid")

    status: str
    """Health check status: 'healthy' or 'unhealthy'."""
    error: str | None = None
    """Error message if status is 'unhealthy', None otherwise."""
    checked_entity: str | None = None
    """Entity name used for the health check."""
    checked_action: str | None = None
    """Action name used for the health check."""


# ===== RESPONSE ENVELOPE MODELS =====

# Type variables for generic envelope models
T = TypeVar('T')
S = TypeVar('S')


class ConfluenceExecuteResult(BaseModel, Generic[T]):
    """Response envelope with data only.

    Used for actions that return data without metadata.
    """
    model_config = ConfigDict(extra="forbid")

    data: T
    """Response data containing the result of the action."""


class ConfluenceExecuteResultWithMeta(ConfluenceExecuteResult[T], Generic[T, S]):
    """Response envelope with data and metadata.

    Used for actions that return both data and metadata (e.g., pagination info).
    """
    meta: S
    """Metadata about the response (e.g., pagination cursors, record counts)."""

# ===== SEARCH DATA MODELS =====
# Entity-specific Pydantic models for search result data

# Type variable for search data generic
D = TypeVar('D')

class AuditSearchData(BaseModel):
    """Search result data for audit entity."""
    model_config = ConfigDict(extra="allow")

    affected_object: dict[str, Any] | None = None
    """The object that was affected by the audit event."""
    associated_objects: list[Any] | None = None
    """Any associated objects related to the audit event."""
    author: dict[str, Any] | None = None
    """The user who triggered the audit event."""
    category: str | None = None
    """The category under which the audit event falls."""
    changed_values: list[Any] | None = None
    """Details of the values that were changed during the audit event."""
    creation_date: int | None = None
    """The date and time when the audit event was created."""
    description: str | None = None
    """A detailed description of the audit event."""
    remote_address: str | None = None
    """The IP address from which the audit event originated."""
    summary: str | None = None
    """A brief summary or title describing the audit event."""
    super_admin: bool | None = None
    """Indicates if the user triggering the audit event is a super admin."""
    sys_admin: bool | None = None
    """Indicates if the user triggering the audit event is a system admin."""


class BlogPostsSearchData(BaseModel):
    """Search result data for blog_posts entity."""
    model_config = ConfigDict(extra="allow")

    links: dict[str, Any] | None = None
    """Links related to the blog post"""
    author_id: str | None = None
    """ID of the user who created the blog post"""
    body: dict[str, Any] | None = None
    """Blog post body content"""
    created_at: str | None = None
    """Timestamp when the blog post was created"""
    id: str | None = None
    """Unique blog post identifier"""
    space_id: str | None = None
    """ID of the space containing this blog post"""
    status: str | None = None
    """Blog post status (current, draft, trashed)"""
    title: str | None = None
    """Blog post title"""
    version: dict[str, Any] | None = None
    """Version information"""


class GroupsSearchData(BaseModel):
    """Search result data for groups entity."""
    model_config = ConfigDict(extra="allow")

    links: dict[str, Any] | None = None
    """Links related to the group"""
    id: str | None = None
    """The unique identifier of the group"""
    name: str | None = None
    """The name of the group"""
    type_: str | None = None
    """The type of group"""


class PagesSearchData(BaseModel):
    """Search result data for pages entity."""
    model_config = ConfigDict(extra="allow")

    links: dict[str, Any] | None = None
    """Links related to the page"""
    author_id: str | None = None
    """ID of the user who created the page"""
    body: dict[str, Any] | None = None
    """Page body content"""
    created_at: str | None = None
    """Timestamp when the page was created"""
    id: str | None = None
    """Unique page identifier"""
    last_owner_id: str | None = None
    """ID of the previous page owner"""
    owner_id: str | None = None
    """ID of the current page owner"""
    parent_id: str | None = None
    """ID of the parent page"""
    parent_type: str | None = None
    """Type of the parent (page or space)"""
    position: int | None = None
    """Position of the page among siblings"""
    space_id: str | None = None
    """ID of the space containing this page"""
    status: str | None = None
    """Page status (current, archived, trashed, draft)"""
    title: str | None = None
    """Page title"""
    version: dict[str, Any] | None = None
    """Version information"""


class SpacesSearchData(BaseModel):
    """Search result data for spaces entity."""
    model_config = ConfigDict(extra="allow")

    links: dict[str, Any] | None = None
    """Links related to the space"""
    author_id: str | None = None
    """ID of the user who created the space"""
    created_at: str | None = None
    """Timestamp when the space was created"""
    description: dict[str, Any] | None = None
    """Space description in various formats"""
    homepage_id: str | None = None
    """ID of the space homepage"""
    icon: dict[str, Any] | None = None
    """Space icon information"""
    id: str | None = None
    """Unique space identifier"""
    key: str | None = None
    """Space key"""
    name: str | None = None
    """Space name"""
    status: str | None = None
    """Space status (current or archived)"""
    type_: str | None = None
    """Space type (global or personal)"""


# ===== GENERIC SEARCH RESULT TYPES =====

class AirbyteSearchMeta(BaseModel):
    """Pagination metadata for search responses."""
    model_config = ConfigDict(extra="allow")

    has_more: bool = False
    """Whether more results are available."""
    cursor: str | None = None
    """Cursor for fetching the next page of results."""
    took_ms: int | None = None
    """Time taken to execute the search in milliseconds."""


class AirbyteSearchResult(BaseModel, Generic[D]):
    """Result from Airbyte cache search operations with typed records."""
    model_config = ConfigDict(extra="allow")

    data: list[D] = Field(default_factory=list)
    """List of matching records."""
    meta: AirbyteSearchMeta = Field(default_factory=AirbyteSearchMeta)
    """Pagination metadata."""


# ===== ENTITY-SPECIFIC SEARCH RESULT TYPE ALIASES =====

AuditSearchResult = AirbyteSearchResult[AuditSearchData]
"""Search result type for audit entity."""

BlogPostsSearchResult = AirbyteSearchResult[BlogPostsSearchData]
"""Search result type for blog_posts entity."""

GroupsSearchResult = AirbyteSearchResult[GroupsSearchData]
"""Search result type for groups entity."""

PagesSearchResult = AirbyteSearchResult[PagesSearchData]
"""Search result type for pages entity."""

SpacesSearchResult = AirbyteSearchResult[SpacesSearchData]
"""Search result type for spaces entity."""



# ===== OPERATION RESULT TYPE ALIASES =====

# Concrete type aliases for each operation result.
# These provide simpler, more readable type annotations than using the generic forms.

SpacesListResult = ConfluenceExecuteResultWithMeta[list[Space], SpacesListResultMeta]
"""Result type for spaces.list operation with data and metadata."""

PagesListResult = ConfluenceExecuteResultWithMeta[list[Page], PagesListResultMeta]
"""Result type for pages.list operation with data and metadata."""

BlogPostsListResult = ConfluenceExecuteResultWithMeta[list[BlogPost], BlogPostsListResultMeta]
"""Result type for blog_posts.list operation with data and metadata."""

GroupsListResult = ConfluenceExecuteResultWithMeta[list[Group], GroupsListResultMeta]
"""Result type for groups.list operation with data and metadata."""

AuditListResult = ConfluenceExecuteResultWithMeta[list[AuditRecord], AuditListResultMeta]
"""Result type for audit.list operation with data and metadata."""




"""
Connector model for confluence.

This file is auto-generated from the connector definition at build time.
DO NOT EDIT MANUALLY - changes will be overwritten on next generation.
"""

from __future__ import annotations

from ._vendored.connector_sdk.types import (
    Action,
    AuthConfig,
    AuthType,
    ConnectorModel,
    EndpointDefinition,
    EntityDefinition,
)
from ._vendored.connector_sdk.schema.security import (
    AirbyteAuthConfig,
    AuthConfigFieldSpec,
)
from uuid import (
    UUID,
)

ConfluenceConnectorModel: ConnectorModel = ConnectorModel(
    id=UUID('cf40a7f8-71f8-45ce-a7fa-fca053e4028c'),
    name='confluence',
    base_url='https://{subdomain}.atlassian.net',
    auth=AuthConfig(
        type=AuthType.BASIC,
        user_config_spec=AirbyteAuthConfig(
            title='Confluence API Token Authentication',
            description='Authenticate using your Atlassian account email and API token',
            type='object',
            required=['username', 'password'],
            properties={
                'username': AuthConfigFieldSpec(
                    title='Email Address',
                    description='Your Atlassian account email address',
                    format='email',
                ),
                'password': AuthConfigFieldSpec(
                    title='API Token',
                    description='Your Confluence API token from https://id.atlassian.com/manage-profile/security/api-tokens',
                ),
            },
            auth_mapping={'username': '${username}', 'password': '${password}'},
            replication_auth_key_mapping={'email': 'username', 'api_token': 'password'},
        ),
    ),
    entities=[
        EntityDefinition(
            name='spaces',
            actions=[Action.LIST, Action.GET],
            endpoints={
                Action.LIST: EndpointDefinition(
                    method='GET',
                    path='/wiki/api/v2/spaces',
                    action=Action.LIST,
                    description='Returns all spaces. Only spaces that the user has permission to view will be returned.',
                    query_params=[
                        'cursor',
                        'limit',
                        'type',
                        'status',
                        'keys',
                        'sort',
                    ],
                    query_params_schema={
                        'cursor': {'type': 'string', 'required': False},
                        'limit': {
                            'type': 'integer',
                            'required': False,
                            'default': 25,
                        },
                        'type': {'type': 'string', 'required': False},
                        'status': {'type': 'string', 'required': False},
                        'keys': {'type': 'array', 'required': False},
                        'sort': {'type': 'string', 'required': False},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Paginated list of spaces',
                        'properties': {
                            'results': {
                                'type': 'array',
                                'items': {
                                    'type': 'object',
                                    'description': 'Confluence space object',
                                    'properties': {
                                        'id': {'type': 'string', 'description': 'Unique space identifier'},
                                        'key': {'type': 'string', 'description': 'Space key'},
                                        'name': {'type': 'string', 'description': 'Space name'},
                                        'type': {'type': 'string', 'description': 'Space type (global or personal)'},
                                        'status': {'type': 'string', 'description': 'Space status (current or archived)'},
                                        'authorId': {'type': 'string', 'description': 'ID of the user who created the space'},
                                        'createdAt': {
                                            'type': 'string',
                                            'format': 'date-time',
                                            'description': 'Timestamp when the space was created',
                                        },
                                        'homepageId': {'type': 'string', 'description': 'ID of the space homepage'},
                                        'spaceOwnerId': {'type': 'string', 'description': 'ID of the space owner'},
                                        'currentActiveAlias': {'type': 'string', 'description': 'Currently active alias for the space'},
                                        'description': {
                                            'oneOf': [
                                                {
                                                    'type': 'object',
                                                    'properties': {
                                                        'plain': {'type': 'object'},
                                                        'view': {'type': 'object'},
                                                    },
                                                },
                                                {'type': 'null'},
                                            ],
                                            'description': 'Space description in various formats',
                                        },
                                        'icon': {
                                            'oneOf': [
                                                {
                                                    'type': 'object',
                                                    'properties': {
                                                        'path': {'type': 'string', 'description': 'Path to the icon'},
                                                        'apiDownloadLink': {'type': 'string', 'description': 'API download link for the icon'},
                                                    },
                                                },
                                                {'type': 'null'},
                                            ],
                                            'description': 'Space icon information',
                                        },
                                        '_links': {
                                            'type': 'object',
                                            'description': 'Links related to the space',
                                            'properties': {
                                                'webui': {'type': 'string', 'description': 'Web UI link'},
                                                'base': {'type': 'string', 'description': 'Base URL'},
                                            },
                                        },
                                    },
                                    'x-airbyte-entity-name': 'spaces',
                                },
                            },
                            '_links': {
                                'type': 'object',
                                'properties': {
                                    'next': {'type': 'string', 'description': 'URL for the next page of results'},
                                    'base': {'type': 'string', 'description': 'Base URL'},
                                },
                            },
                        },
                    },
                    record_extractor='$.results',
                    meta_extractor={'next': '$._links.next'},
                    preferred_for_check=True,
                ),
                Action.GET: EndpointDefinition(
                    method='GET',
                    path='/wiki/api/v2/spaces/{id}',
                    action=Action.GET,
                    description='Returns a specific space.',
                    query_params=['description-format'],
                    query_params_schema={
                        'description-format': {'type': 'string', 'required': False},
                    },
                    path_params=['id'],
                    path_params_schema={
                        'id': {'type': 'string', 'required': True},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Confluence space object',
                        'properties': {
                            'id': {'type': 'string', 'description': 'Unique space identifier'},
                            'key': {'type': 'string', 'description': 'Space key'},
                            'name': {'type': 'string', 'description': 'Space name'},
                            'type': {'type': 'string', 'description': 'Space type (global or personal)'},
                            'status': {'type': 'string', 'description': 'Space status (current or archived)'},
                            'authorId': {'type': 'string', 'description': 'ID of the user who created the space'},
                            'createdAt': {
                                'type': 'string',
                                'format': 'date-time',
                                'description': 'Timestamp when the space was created',
                            },
                            'homepageId': {'type': 'string', 'description': 'ID of the space homepage'},
                            'spaceOwnerId': {'type': 'string', 'description': 'ID of the space owner'},
                            'currentActiveAlias': {'type': 'string', 'description': 'Currently active alias for the space'},
                            'description': {
                                'oneOf': [
                                    {
                                        'type': 'object',
                                        'properties': {
                                            'plain': {'type': 'object'},
                                            'view': {'type': 'object'},
                                        },
                                    },
                                    {'type': 'null'},
                                ],
                                'description': 'Space description in various formats',
                            },
                            'icon': {
                                'oneOf': [
                                    {
                                        'type': 'object',
                                        'properties': {
                                            'path': {'type': 'string', 'description': 'Path to the icon'},
                                            'apiDownloadLink': {'type': 'string', 'description': 'API download link for the icon'},
                                        },
                                    },
                                    {'type': 'null'},
                                ],
                                'description': 'Space icon information',
                            },
                            '_links': {
                                'type': 'object',
                                'description': 'Links related to the space',
                                'properties': {
                                    'webui': {'type': 'string', 'description': 'Web UI link'},
                                    'base': {'type': 'string', 'description': 'Base URL'},
                                },
                            },
                        },
                        'x-airbyte-entity-name': 'spaces',
                    },
                ),
            },
            entity_schema={
                'type': 'object',
                'description': 'Confluence space object',
                'properties': {
                    'id': {'type': 'string', 'description': 'Unique space identifier'},
                    'key': {'type': 'string', 'description': 'Space key'},
                    'name': {'type': 'string', 'description': 'Space name'},
                    'type': {'type': 'string', 'description': 'Space type (global or personal)'},
                    'status': {'type': 'string', 'description': 'Space status (current or archived)'},
                    'authorId': {'type': 'string', 'description': 'ID of the user who created the space'},
                    'createdAt': {
                        'type': 'string',
                        'format': 'date-time',
                        'description': 'Timestamp when the space was created',
                    },
                    'homepageId': {'type': 'string', 'description': 'ID of the space homepage'},
                    'spaceOwnerId': {'type': 'string', 'description': 'ID of the space owner'},
                    'currentActiveAlias': {'type': 'string', 'description': 'Currently active alias for the space'},
                    'description': {
                        'oneOf': [
                            {
                                'type': 'object',
                                'properties': {
                                    'plain': {'type': 'object'},
                                    'view': {'type': 'object'},
                                },
                            },
                            {'type': 'null'},
                        ],
                        'description': 'Space description in various formats',
                    },
                    'icon': {
                        'oneOf': [
                            {
                                'type': 'object',
                                'properties': {
                                    'path': {'type': 'string', 'description': 'Path to the icon'},
                                    'apiDownloadLink': {'type': 'string', 'description': 'API download link for the icon'},
                                },
                            },
                            {'type': 'null'},
                        ],
                        'description': 'Space icon information',
                    },
                    '_links': {
                        'type': 'object',
                        'description': 'Links related to the space',
                        'properties': {
                            'webui': {'type': 'string', 'description': 'Web UI link'},
                            'base': {'type': 'string', 'description': 'Base URL'},
                        },
                    },
                },
                'x-airbyte-entity-name': 'spaces',
            },
        ),
        EntityDefinition(
            name='pages',
            actions=[Action.LIST, Action.GET],
            endpoints={
                Action.LIST: EndpointDefinition(
                    method='GET',
                    path='/wiki/api/v2/pages',
                    action=Action.LIST,
                    description='Returns all pages. Only pages that the user has permission to view will be returned.',
                    query_params=[
                        'cursor',
                        'limit',
                        'space-id',
                        'title',
                        'status',
                        'sort',
                        'body-format',
                    ],
                    query_params_schema={
                        'cursor': {'type': 'string', 'required': False},
                        'limit': {
                            'type': 'integer',
                            'required': False,
                            'default': 25,
                        },
                        'space-id': {'type': 'array', 'required': False},
                        'title': {'type': 'string', 'required': False},
                        'status': {'type': 'array', 'required': False},
                        'sort': {'type': 'string', 'required': False},
                        'body-format': {'type': 'string', 'required': False},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Paginated list of pages',
                        'properties': {
                            'results': {
                                'type': 'array',
                                'items': {
                                    'type': 'object',
                                    'description': 'Confluence page object',
                                    'properties': {
                                        'id': {'type': 'string', 'description': 'Unique page identifier'},
                                        'status': {'type': 'string', 'description': 'Page status (current, archived, trashed, draft)'},
                                        'title': {'type': 'string', 'description': 'Page title'},
                                        'spaceId': {'type': 'string', 'description': 'ID of the space containing this page'},
                                        'parentId': {
                                            'oneOf': [
                                                {'type': 'string'},
                                                {'type': 'null'},
                                            ],
                                            'description': 'ID of the parent page',
                                        },
                                        'parentType': {
                                            'oneOf': [
                                                {'type': 'string'},
                                                {'type': 'null'},
                                            ],
                                            'description': 'Type of the parent (page or space)',
                                        },
                                        'position': {'type': 'integer', 'description': 'Position of the page among siblings'},
                                        'authorId': {'type': 'string', 'description': 'ID of the user who created the page'},
                                        'ownerId': {'type': 'string', 'description': 'ID of the current page owner'},
                                        'lastOwnerId': {
                                            'oneOf': [
                                                {'type': 'string'},
                                                {'type': 'null'},
                                            ],
                                            'description': 'ID of the previous page owner',
                                        },
                                        'createdAt': {
                                            'type': 'string',
                                            'format': 'date-time',
                                            'description': 'Timestamp when the page was created',
                                        },
                                        'version': {
                                            'type': 'object',
                                            'description': 'Version information',
                                            'properties': {
                                                'createdAt': {
                                                    'type': 'string',
                                                    'format': 'date-time',
                                                    'description': 'Version creation timestamp',
                                                },
                                                'message': {'type': 'string', 'description': 'Version message'},
                                                'number': {'type': 'integer', 'description': 'Version number'},
                                                'minorEdit': {'type': 'boolean', 'description': 'Whether this was a minor edit'},
                                                'authorId': {'type': 'string', 'description': 'ID of the version author'},
                                                'ncsStepVersion': {
                                                    'oneOf': [
                                                        {'type': 'string'},
                                                        {'type': 'null'},
                                                    ],
                                                    'description': 'NCS step version',
                                                },
                                            },
                                        },
                                        'body': {
                                            'type': 'object',
                                            'description': 'Page body content',
                                            'properties': {
                                                'storage': {'type': 'object', 'description': 'Storage format body'},
                                                'atlas_doc_format': {'type': 'object', 'description': 'Atlas doc format body'},
                                            },
                                        },
                                        '_links': {
                                            'type': 'object',
                                            'description': 'Links related to the page',
                                            'properties': {
                                                'webui': {'type': 'string', 'description': 'Web UI link'},
                                                'editui': {'type': 'string', 'description': 'Edit UI link'},
                                                'edituiv2': {'type': 'string', 'description': 'Edit UI v2 link'},
                                                'tinyui': {'type': 'string', 'description': 'Tiny UI link'},
                                                'base': {'type': 'string', 'description': 'Base URL'},
                                            },
                                        },
                                    },
                                    'x-airbyte-entity-name': 'pages',
                                },
                            },
                            '_links': {
                                'type': 'object',
                                'properties': {
                                    'next': {'type': 'string', 'description': 'URL for the next page of results'},
                                    'base': {'type': 'string', 'description': 'Base URL'},
                                },
                            },
                        },
                    },
                    record_extractor='$.results',
                    meta_extractor={'next': '$._links.next'},
                ),
                Action.GET: EndpointDefinition(
                    method='GET',
                    path='/wiki/api/v2/pages/{id}',
                    action=Action.GET,
                    description='Returns a specific page.',
                    query_params=['body-format', 'version'],
                    query_params_schema={
                        'body-format': {'type': 'string', 'required': False},
                        'version': {'type': 'integer', 'required': False},
                    },
                    path_params=['id'],
                    path_params_schema={
                        'id': {'type': 'string', 'required': True},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Confluence page object',
                        'properties': {
                            'id': {'type': 'string', 'description': 'Unique page identifier'},
                            'status': {'type': 'string', 'description': 'Page status (current, archived, trashed, draft)'},
                            'title': {'type': 'string', 'description': 'Page title'},
                            'spaceId': {'type': 'string', 'description': 'ID of the space containing this page'},
                            'parentId': {
                                'oneOf': [
                                    {'type': 'string'},
                                    {'type': 'null'},
                                ],
                                'description': 'ID of the parent page',
                            },
                            'parentType': {
                                'oneOf': [
                                    {'type': 'string'},
                                    {'type': 'null'},
                                ],
                                'description': 'Type of the parent (page or space)',
                            },
                            'position': {'type': 'integer', 'description': 'Position of the page among siblings'},
                            'authorId': {'type': 'string', 'description': 'ID of the user who created the page'},
                            'ownerId': {'type': 'string', 'description': 'ID of the current page owner'},
                            'lastOwnerId': {
                                'oneOf': [
                                    {'type': 'string'},
                                    {'type': 'null'},
                                ],
                                'description': 'ID of the previous page owner',
                            },
                            'createdAt': {
                                'type': 'string',
                                'format': 'date-time',
                                'description': 'Timestamp when the page was created',
                            },
                            'version': {
                                'type': 'object',
                                'description': 'Version information',
                                'properties': {
                                    'createdAt': {
                                        'type': 'string',
                                        'format': 'date-time',
                                        'description': 'Version creation timestamp',
                                    },
                                    'message': {'type': 'string', 'description': 'Version message'},
                                    'number': {'type': 'integer', 'description': 'Version number'},
                                    'minorEdit': {'type': 'boolean', 'description': 'Whether this was a minor edit'},
                                    'authorId': {'type': 'string', 'description': 'ID of the version author'},
                                    'ncsStepVersion': {
                                        'oneOf': [
                                            {'type': 'string'},
                                            {'type': 'null'},
                                        ],
                                        'description': 'NCS step version',
                                    },
                                },
                            },
                            'body': {
                                'type': 'object',
                                'description': 'Page body content',
                                'properties': {
                                    'storage': {'type': 'object', 'description': 'Storage format body'},
                                    'atlas_doc_format': {'type': 'object', 'description': 'Atlas doc format body'},
                                },
                            },
                            '_links': {
                                'type': 'object',
                                'description': 'Links related to the page',
                                'properties': {
                                    'webui': {'type': 'string', 'description': 'Web UI link'},
                                    'editui': {'type': 'string', 'description': 'Edit UI link'},
                                    'edituiv2': {'type': 'string', 'description': 'Edit UI v2 link'},
                                    'tinyui': {'type': 'string', 'description': 'Tiny UI link'},
                                    'base': {'type': 'string', 'description': 'Base URL'},
                                },
                            },
                        },
                        'x-airbyte-entity-name': 'pages',
                    },
                ),
            },
            entity_schema={
                'type': 'object',
                'description': 'Confluence page object',
                'properties': {
                    'id': {'type': 'string', 'description': 'Unique page identifier'},
                    'status': {'type': 'string', 'description': 'Page status (current, archived, trashed, draft)'},
                    'title': {'type': 'string', 'description': 'Page title'},
                    'spaceId': {'type': 'string', 'description': 'ID of the space containing this page'},
                    'parentId': {
                        'oneOf': [
                            {'type': 'string'},
                            {'type': 'null'},
                        ],
                        'description': 'ID of the parent page',
                    },
                    'parentType': {
                        'oneOf': [
                            {'type': 'string'},
                            {'type': 'null'},
                        ],
                        'description': 'Type of the parent (page or space)',
                    },
                    'position': {'type': 'integer', 'description': 'Position of the page among siblings'},
                    'authorId': {'type': 'string', 'description': 'ID of the user who created the page'},
                    'ownerId': {'type': 'string', 'description': 'ID of the current page owner'},
                    'lastOwnerId': {
                        'oneOf': [
                            {'type': 'string'},
                            {'type': 'null'},
                        ],
                        'description': 'ID of the previous page owner',
                    },
                    'createdAt': {
                        'type': 'string',
                        'format': 'date-time',
                        'description': 'Timestamp when the page was created',
                    },
                    'version': {
                        'type': 'object',
                        'description': 'Version information',
                        'properties': {
                            'createdAt': {
                                'type': 'string',
                                'format': 'date-time',
                                'description': 'Version creation timestamp',
                            },
                            'message': {'type': 'string', 'description': 'Version message'},
                            'number': {'type': 'integer', 'description': 'Version number'},
                            'minorEdit': {'type': 'boolean', 'description': 'Whether this was a minor edit'},
                            'authorId': {'type': 'string', 'description': 'ID of the version author'},
                            'ncsStepVersion': {
                                'oneOf': [
                                    {'type': 'string'},
                                    {'type': 'null'},
                                ],
                                'description': 'NCS step version',
                            },
                        },
                    },
                    'body': {
                        'type': 'object',
                        'description': 'Page body content',
                        'properties': {
                            'storage': {'type': 'object', 'description': 'Storage format body'},
                            'atlas_doc_format': {'type': 'object', 'description': 'Atlas doc format body'},
                        },
                    },
                    '_links': {
                        'type': 'object',
                        'description': 'Links related to the page',
                        'properties': {
                            'webui': {'type': 'string', 'description': 'Web UI link'},
                            'editui': {'type': 'string', 'description': 'Edit UI link'},
                            'edituiv2': {'type': 'string', 'description': 'Edit UI v2 link'},
                            'tinyui': {'type': 'string', 'description': 'Tiny UI link'},
                            'base': {'type': 'string', 'description': 'Base URL'},
                        },
                    },
                },
                'x-airbyte-entity-name': 'pages',
            },
        ),
        EntityDefinition(
            name='blog_posts',
            actions=[Action.LIST, Action.GET],
            endpoints={
                Action.LIST: EndpointDefinition(
                    method='GET',
                    path='/wiki/api/v2/blogposts',
                    action=Action.LIST,
                    description='Returns all blog posts. Only blog posts that the user has permission to view will be returned.',
                    query_params=[
                        'cursor',
                        'limit',
                        'space-id',
                        'title',
                        'status',
                        'sort',
                        'body-format',
                    ],
                    query_params_schema={
                        'cursor': {'type': 'string', 'required': False},
                        'limit': {
                            'type': 'integer',
                            'required': False,
                            'default': 25,
                        },
                        'space-id': {'type': 'array', 'required': False},
                        'title': {'type': 'string', 'required': False},
                        'status': {'type': 'array', 'required': False},
                        'sort': {'type': 'string', 'required': False},
                        'body-format': {'type': 'string', 'required': False},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Paginated list of blog posts',
                        'properties': {
                            'results': {
                                'type': 'array',
                                'items': {
                                    'type': 'object',
                                    'description': 'Confluence blog post object',
                                    'properties': {
                                        'id': {'type': 'string', 'description': 'Unique blog post identifier'},
                                        'status': {'type': 'string', 'description': 'Blog post status (current, draft, trashed)'},
                                        'title': {'type': 'string', 'description': 'Blog post title'},
                                        'spaceId': {'type': 'string', 'description': 'ID of the space containing this blog post'},
                                        'authorId': {'type': 'string', 'description': 'ID of the user who created the blog post'},
                                        'createdAt': {
                                            'type': 'string',
                                            'format': 'date-time',
                                            'description': 'Timestamp when the blog post was created',
                                        },
                                        'version': {
                                            'type': 'object',
                                            'description': 'Version information',
                                            'properties': {
                                                'createdAt': {
                                                    'type': 'string',
                                                    'format': 'date-time',
                                                    'description': 'Version creation timestamp',
                                                },
                                                'message': {'type': 'string', 'description': 'Version message'},
                                                'number': {'type': 'integer', 'description': 'Version number'},
                                                'minorEdit': {'type': 'boolean', 'description': 'Whether this was a minor edit'},
                                                'authorId': {'type': 'string', 'description': 'ID of the version author'},
                                                'ncsStepVersion': {
                                                    'oneOf': [
                                                        {'type': 'string'},
                                                        {'type': 'null'},
                                                    ],
                                                    'description': 'NCS step version',
                                                },
                                            },
                                        },
                                        'body': {
                                            'type': 'object',
                                            'description': 'Blog post body content',
                                            'properties': {
                                                'storage': {'type': 'object', 'description': 'Storage format body'},
                                                'atlas_doc_format': {'type': 'object', 'description': 'Atlas doc format body'},
                                            },
                                        },
                                        '_links': {
                                            'type': 'object',
                                            'description': 'Links related to the blog post',
                                            'properties': {
                                                'webui': {'type': 'string', 'description': 'Web UI link'},
                                                'editui': {'type': 'string', 'description': 'Edit UI link'},
                                                'edituiv2': {'type': 'string', 'description': 'Edit UI v2 link'},
                                                'tinyui': {'type': 'string', 'description': 'Tiny UI link'},
                                                'base': {'type': 'string', 'description': 'Base URL'},
                                            },
                                        },
                                    },
                                    'x-airbyte-entity-name': 'blog_posts',
                                },
                            },
                            '_links': {
                                'type': 'object',
                                'properties': {
                                    'next': {'type': 'string', 'description': 'URL for the next page of results'},
                                    'base': {'type': 'string', 'description': 'Base URL'},
                                },
                            },
                        },
                    },
                    record_extractor='$.results',
                    meta_extractor={'next': '$._links.next'},
                ),
                Action.GET: EndpointDefinition(
                    method='GET',
                    path='/wiki/api/v2/blogposts/{id}',
                    action=Action.GET,
                    description='Returns a specific blog post.',
                    query_params=['body-format', 'version'],
                    query_params_schema={
                        'body-format': {'type': 'string', 'required': False},
                        'version': {'type': 'integer', 'required': False},
                    },
                    path_params=['id'],
                    path_params_schema={
                        'id': {'type': 'string', 'required': True},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Confluence blog post object',
                        'properties': {
                            'id': {'type': 'string', 'description': 'Unique blog post identifier'},
                            'status': {'type': 'string', 'description': 'Blog post status (current, draft, trashed)'},
                            'title': {'type': 'string', 'description': 'Blog post title'},
                            'spaceId': {'type': 'string', 'description': 'ID of the space containing this blog post'},
                            'authorId': {'type': 'string', 'description': 'ID of the user who created the blog post'},
                            'createdAt': {
                                'type': 'string',
                                'format': 'date-time',
                                'description': 'Timestamp when the blog post was created',
                            },
                            'version': {
                                'type': 'object',
                                'description': 'Version information',
                                'properties': {
                                    'createdAt': {
                                        'type': 'string',
                                        'format': 'date-time',
                                        'description': 'Version creation timestamp',
                                    },
                                    'message': {'type': 'string', 'description': 'Version message'},
                                    'number': {'type': 'integer', 'description': 'Version number'},
                                    'minorEdit': {'type': 'boolean', 'description': 'Whether this was a minor edit'},
                                    'authorId': {'type': 'string', 'description': 'ID of the version author'},
                                    'ncsStepVersion': {
                                        'oneOf': [
                                            {'type': 'string'},
                                            {'type': 'null'},
                                        ],
                                        'description': 'NCS step version',
                                    },
                                },
                            },
                            'body': {
                                'type': 'object',
                                'description': 'Blog post body content',
                                'properties': {
                                    'storage': {'type': 'object', 'description': 'Storage format body'},
                                    'atlas_doc_format': {'type': 'object', 'description': 'Atlas doc format body'},
                                },
                            },
                            '_links': {
                                'type': 'object',
                                'description': 'Links related to the blog post',
                                'properties': {
                                    'webui': {'type': 'string', 'description': 'Web UI link'},
                                    'editui': {'type': 'string', 'description': 'Edit UI link'},
                                    'edituiv2': {'type': 'string', 'description': 'Edit UI v2 link'},
                                    'tinyui': {'type': 'string', 'description': 'Tiny UI link'},
                                    'base': {'type': 'string', 'description': 'Base URL'},
                                },
                            },
                        },
                        'x-airbyte-entity-name': 'blog_posts',
                    },
                ),
            },
            entity_schema={
                'type': 'object',
                'description': 'Confluence blog post object',
                'properties': {
                    'id': {'type': 'string', 'description': 'Unique blog post identifier'},
                    'status': {'type': 'string', 'description': 'Blog post status (current, draft, trashed)'},
                    'title': {'type': 'string', 'description': 'Blog post title'},
                    'spaceId': {'type': 'string', 'description': 'ID of the space containing this blog post'},
                    'authorId': {'type': 'string', 'description': 'ID of the user who created the blog post'},
                    'createdAt': {
                        'type': 'string',
                        'format': 'date-time',
                        'description': 'Timestamp when the blog post was created',
                    },
                    'version': {
                        'type': 'object',
                        'description': 'Version information',
                        'properties': {
                            'createdAt': {
                                'type': 'string',
                                'format': 'date-time',
                                'description': 'Version creation timestamp',
                            },
                            'message': {'type': 'string', 'description': 'Version message'},
                            'number': {'type': 'integer', 'description': 'Version number'},
                            'minorEdit': {'type': 'boolean', 'description': 'Whether this was a minor edit'},
                            'authorId': {'type': 'string', 'description': 'ID of the version author'},
                            'ncsStepVersion': {
                                'oneOf': [
                                    {'type': 'string'},
                                    {'type': 'null'},
                                ],
                                'description': 'NCS step version',
                            },
                        },
                    },
                    'body': {
                        'type': 'object',
                        'description': 'Blog post body content',
                        'properties': {
                            'storage': {'type': 'object', 'description': 'Storage format body'},
                            'atlas_doc_format': {'type': 'object', 'description': 'Atlas doc format body'},
                        },
                    },
                    '_links': {
                        'type': 'object',
                        'description': 'Links related to the blog post',
                        'properties': {
                            'webui': {'type': 'string', 'description': 'Web UI link'},
                            'editui': {'type': 'string', 'description': 'Edit UI link'},
                            'edituiv2': {'type': 'string', 'description': 'Edit UI v2 link'},
                            'tinyui': {'type': 'string', 'description': 'Tiny UI link'},
                            'base': {'type': 'string', 'description': 'Base URL'},
                        },
                    },
                },
                'x-airbyte-entity-name': 'blog_posts',
            },
        ),
        EntityDefinition(
            name='groups',
            actions=[Action.LIST],
            endpoints={
                Action.LIST: EndpointDefinition(
                    method='GET',
                    path='/wiki/rest/api/group',
                    action=Action.LIST,
                    description='Returns all user groups.',
                    query_params=['start', 'limit'],
                    query_params_schema={
                        'start': {
                            'type': 'integer',
                            'required': False,
                            'default': 0,
                        },
                        'limit': {
                            'type': 'integer',
                            'required': False,
                            'default': 25,
                        },
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Paginated list of groups',
                        'properties': {
                            'results': {
                                'type': 'array',
                                'items': {
                                    'type': 'object',
                                    'description': 'Confluence group object',
                                    'properties': {
                                        'type': {'type': 'string', 'description': 'Type of the group'},
                                        'id': {'type': 'string', 'description': 'Unique group identifier'},
                                        'name': {'type': 'string', 'description': 'Group name'},
                                        'managedBy': {'type': 'string', 'description': 'Entity managing this group'},
                                        'usageType': {'type': 'string', 'description': 'Usage type of the group'},
                                        'resourceAri': {'type': 'string', 'description': 'Atlassian Resource Identifier for the group'},
                                        '_links': {
                                            'type': 'object',
                                            'description': 'Links related to the group',
                                            'properties': {
                                                'self': {'type': 'string', 'description': 'Self link'},
                                            },
                                        },
                                    },
                                    'x-airbyte-entity-name': 'groups',
                                },
                            },
                            'start': {'type': 'integer', 'description': 'Starting index'},
                            'limit': {'type': 'integer', 'description': 'Number of results per page'},
                            'size': {'type': 'integer', 'description': 'Number of results returned'},
                            '_links': {
                                'type': 'object',
                                'properties': {
                                    'base': {'type': 'string'},
                                    'context': {'type': 'string'},
                                    'next': {'type': 'string'},
                                    'self': {'type': 'string'},
                                },
                            },
                        },
                    },
                    record_extractor='$.results',
                    meta_extractor={
                        'start': '$.start',
                        'limit': '$.limit',
                        'size': '$.size',
                    },
                ),
            },
            entity_schema={
                'type': 'object',
                'description': 'Confluence group object',
                'properties': {
                    'type': {'type': 'string', 'description': 'Type of the group'},
                    'id': {'type': 'string', 'description': 'Unique group identifier'},
                    'name': {'type': 'string', 'description': 'Group name'},
                    'managedBy': {'type': 'string', 'description': 'Entity managing this group'},
                    'usageType': {'type': 'string', 'description': 'Usage type of the group'},
                    'resourceAri': {'type': 'string', 'description': 'Atlassian Resource Identifier for the group'},
                    '_links': {
                        'type': 'object',
                        'description': 'Links related to the group',
                        'properties': {
                            'self': {'type': 'string', 'description': 'Self link'},
                        },
                    },
                },
                'x-airbyte-entity-name': 'groups',
            },
        ),
        EntityDefinition(
            name='audit',
            actions=[Action.LIST],
            endpoints={
                Action.LIST: EndpointDefinition(
                    method='GET',
                    path='/wiki/rest/api/audit',
                    action=Action.LIST,
                    description='Returns audit log records.',
                    query_params=[
                        'start',
                        'limit',
                        'startDate',
                        'endDate',
                        'searchString',
                    ],
                    query_params_schema={
                        'start': {
                            'type': 'integer',
                            'required': False,
                            'default': 0,
                        },
                        'limit': {
                            'type': 'integer',
                            'required': False,
                            'default': 25,
                        },
                        'startDate': {'type': 'string', 'required': False},
                        'endDate': {'type': 'string', 'required': False},
                        'searchString': {'type': 'string', 'required': False},
                    },
                    response_schema={
                        'type': 'object',
                        'description': 'Paginated list of audit records',
                        'properties': {
                            'results': {
                                'type': 'array',
                                'items': {
                                    'type': 'object',
                                    'description': 'Confluence audit record',
                                    'properties': {
                                        'author': {
                                            'type': 'object',
                                            'description': 'User who triggered the audit event',
                                            'properties': {
                                                'type': {'type': 'string', 'description': 'Author type'},
                                                'displayName': {'type': 'string', 'description': 'Display name of the author'},
                                                'publicName': {'type': 'string', 'description': 'Public name of the author'},
                                                'accountType': {'type': 'string', 'description': 'Account type'},
                                                'isExternalCollaborator': {'type': 'boolean', 'description': 'Whether the author is an external collaborator'},
                                                'externalCollaborator': {'type': 'boolean', 'description': 'Whether the author is an external collaborator'},
                                                'operations': {
                                                    'oneOf': [
                                                        {'type': 'object'},
                                                        {'type': 'null'},
                                                    ],
                                                    'description': 'Operations available for the author',
                                                },
                                            },
                                        },
                                        'remoteAddress': {'type': 'string', 'description': 'IP address from which the event originated'},
                                        'creationDate': {'type': 'integer', 'description': 'Timestamp of the audit event'},
                                        'summary': {'type': 'string', 'description': 'Brief summary of the audit event'},
                                        'description': {'type': 'string', 'description': 'Detailed description of the audit event'},
                                        'category': {'type': 'string', 'description': 'Category of the audit event'},
                                        'sysAdmin': {'type': 'boolean', 'description': 'Whether the user is a system admin'},
                                        'superAdmin': {'type': 'boolean', 'description': 'Whether the user is a super admin'},
                                        'affectedObject': {
                                            'type': 'object',
                                            'description': 'Object affected by the audit event',
                                            'properties': {
                                                'name': {'type': 'string', 'description': 'Name of the affected object'},
                                                'objectType': {'type': 'string', 'description': 'Type of the affected object'},
                                            },
                                        },
                                        'changedValues': {'type': 'array', 'description': 'Values changed during the audit event'},
                                        'associatedObjects': {
                                            'type': 'array',
                                            'description': 'Objects associated with the audit event',
                                            'items': {
                                                'type': 'object',
                                                'properties': {
                                                    'name': {'type': 'string', 'description': 'Name of the associated object'},
                                                    'objectType': {'type': 'string', 'description': 'Type of the associated object'},
                                                },
                                            },
                                        },
                                    },
                                    'x-airbyte-entity-name': 'audit',
                                },
                            },
                            'start': {'type': 'integer', 'description': 'Starting index'},
                            'limit': {'type': 'integer', 'description': 'Number of results per page'},
                            'size': {'type': 'integer', 'description': 'Number of results returned'},
                            '_links': {
                                'type': 'object',
                                'properties': {
                                    'base': {'type': 'string'},
                                    'context': {'type': 'string'},
                                    'next': {'type': 'string'},
                                    'self': {'type': 'string'},
                                },
                            },
                        },
                    },
                    record_extractor='$.results',
                    meta_extractor={
                        'start': '$.start',
                        'limit': '$.limit',
                        'size': '$.size',
                    },
                ),
            },
            entity_schema={
                'type': 'object',
                'description': 'Confluence audit record',
                'properties': {
                    'author': {
                        'type': 'object',
                        'description': 'User who triggered the audit event',
                        'properties': {
                            'type': {'type': 'string', 'description': 'Author type'},
                            'displayName': {'type': 'string', 'description': 'Display name of the author'},
                            'publicName': {'type': 'string', 'description': 'Public name of the author'},
                            'accountType': {'type': 'string', 'description': 'Account type'},
                            'isExternalCollaborator': {'type': 'boolean', 'description': 'Whether the author is an external collaborator'},
                            'externalCollaborator': {'type': 'boolean', 'description': 'Whether the author is an external collaborator'},
                            'operations': {
                                'oneOf': [
                                    {'type': 'object'},
                                    {'type': 'null'},
                                ],
                                'description': 'Operations available for the author',
                            },
                        },
                    },
                    'remoteAddress': {'type': 'string', 'description': 'IP address from which the event originated'},
                    'creationDate': {'type': 'integer', 'description': 'Timestamp of the audit event'},
                    'summary': {'type': 'string', 'description': 'Brief summary of the audit event'},
                    'description': {'type': 'string', 'description': 'Detailed description of the audit event'},
                    'category': {'type': 'string', 'description': 'Category of the audit event'},
                    'sysAdmin': {'type': 'boolean', 'description': 'Whether the user is a system admin'},
                    'superAdmin': {'type': 'boolean', 'description': 'Whether the user is a super admin'},
                    'affectedObject': {
                        'type': 'object',
                        'description': 'Object affected by the audit event',
                        'properties': {
                            'name': {'type': 'string', 'description': 'Name of the affected object'},
                            'objectType': {'type': 'string', 'description': 'Type of the affected object'},
                        },
                    },
                    'changedValues': {'type': 'array', 'description': 'Values changed during the audit event'},
                    'associatedObjects': {
                        'type': 'array',
                        'description': 'Objects associated with the audit event',
                        'items': {
                            'type': 'object',
                            'properties': {
                                'name': {'type': 'string', 'description': 'Name of the associated object'},
                                'objectType': {'type': 'string', 'description': 'Type of the associated object'},
                            },
                        },
                    },
                },
                'x-airbyte-entity-name': 'audit',
            },
        ),
    ],
    search_field_paths={
        'audit': [
            'affectedObject',
            'associatedObjects',
            'associatedObjects[]',
            'author',
            'category',
            'changedValues',
            'changedValues[]',
            'creationDate',
            'description',
            'remoteAddress',
            'summary',
            'superAdmin',
            'sysAdmin',
        ],
        'blog_posts': [
            '_links',
            '_links.webui',
            '_links.editui',
            '_links.tinyui',
            'authorId',
            'body',
            'body.storage',
            'body.atlas_doc_format',
            'createdAt',
            'id',
            'spaceId',
            'status',
            'title',
            'version',
            'version.createdAt',
            'version.message',
            'version.number',
            'version.minorEdit',
            'version.authorId',
        ],
        'groups': [
            '_links',
            'id',
            'name',
            'type',
        ],
        'pages': [
            '_links',
            '_links.webui',
            '_links.editui',
            '_links.tinyui',
            'authorId',
            'body',
            'body.storage',
            'body.atlas_doc_format',
            'createdAt',
            'id',
            'lastOwnerId',
            'ownerId',
            'parentId',
            'parentType',
            'position',
            'spaceId',
            'status',
            'title',
            'version',
            'version.createdAt',
            'version.message',
            'version.number',
            'version.minorEdit',
            'version.authorId',
        ],
        'spaces': [
            '_links',
            '_links.webui',
            'authorId',
            'createdAt',
            'description',
            'description.plain',
            'description.view',
            'homepageId',
            'icon',
            'icon.path',
            'icon.apiDownloadLink',
            'id',
            'key',
            'name',
            'status',
            'type',
        ],
    },
    server_variable_defaults={'subdomain': '{subdomain}'},
)


"""
Type definitions for confluence connector.
"""
from __future__ import annotations

from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig  # noqa: F401

# Use typing_extensions.TypedDict for Pydantic compatibility
try:
    from typing_extensions import TypedDict, NotRequired
except ImportError:
    from typing import TypedDict, NotRequired  # type: ignore[attr-defined]

from typing import Any, Literal


# ===== NESTED PARAM TYPE DEFINITIONS =====
# Nested parameter schemas discovered during parameter extraction

# ===== OPERATION PARAMS TYPE DEFINITIONS =====

class SpacesListParams(TypedDict):
    """Parameters for spaces.list operation"""
    cursor: NotRequired[str]
    limit: NotRequired[int]
    type: NotRequired[str]
    status: NotRequired[str]
    keys: NotRequired[list[str]]
    sort: NotRequired[str]

class SpacesGetParams(TypedDict):
    """Parameters for spaces.get operation"""
    id: str
    description_format: NotRequired[str]

class PagesListParams(TypedDict):
    """Parameters for pages.list operation"""
    cursor: NotRequired[str]
    limit: NotRequired[int]
    space_id: NotRequired[list[int]]
    title: NotRequired[str]
    status: NotRequired[list[str]]
    sort: NotRequired[str]
    body_format: NotRequired[str]

class PagesGetParams(TypedDict):
    """Parameters for pages.get operation"""
    id: str
    body_format: NotRequired[str]
    version: NotRequired[int]

class BlogPostsListParams(TypedDict):
    """Parameters for blog_posts.list operation"""
    cursor: NotRequired[str]
    limit: NotRequired[int]
    space_id: NotRequired[list[int]]
    title: NotRequired[str]
    status: NotRequired[list[str]]
    sort: NotRequired[str]
    body_format: NotRequired[str]

class BlogPostsGetParams(TypedDict):
    """Parameters for blog_posts.get operation"""
    id: str
    body_format: NotRequired[str]
    version: NotRequired[int]

class GroupsListParams(TypedDict):
    """Parameters for groups.list operation"""
    start: NotRequired[int]
    limit: NotRequired[int]

class AuditListParams(TypedDict):
    """Parameters for audit.list operation"""
    start: NotRequired[int]
    limit: NotRequired[int]
    start_date: NotRequired[str]
    end_date: NotRequired[str]
    search_string: NotRequired[str]

# ===== SEARCH TYPES =====

# Sort specification
AirbyteSortOrder = Literal["asc", "desc"]

# ===== AUDIT SEARCH TYPES =====

class AuditSearchFilter(TypedDict, total=False):
    """Available fields for filtering audit search queries."""
    affected_object: dict[str, Any] | None
    """The object that was affected by the audit event."""
    associated_objects: list[Any] | None
    """Any associated objects related to the audit event."""
    author: dict[str, Any] | None
    """The user who triggered the audit event."""
    category: str | None
    """The category under which the audit event falls."""
    changed_values: list[Any] | None
    """Details of the values that were changed during the audit event."""
    creation_date: int | None
    """The date and time when the audit event was created."""
    description: str | None
    """A detailed description of the audit event."""
    remote_address: str | None
    """The IP address from which the audit event originated."""
    summary: str | None
    """A brief summary or title describing the audit event."""
    super_admin: bool | None
    """Indicates if the user triggering the audit event is a super admin."""
    sys_admin: bool | None
    """Indicates if the user triggering the audit event is a system admin."""


class AuditInFilter(TypedDict, total=False):
    """Available fields for 'in' condition (values are lists)."""
    affected_object: list[dict[str, Any]]
    """The object that was affected by the audit event."""
    associated_objects: list[list[Any]]
    """Any associated objects related to the audit event."""
    author: list[dict[str, Any]]
    """The user who triggered the audit event."""
    category: list[str]
    """The category under which the audit event falls."""
    changed_values: list[list[Any]]
    """Details of the values that were changed during the audit event."""
    creation_date: list[int]
    """The date and time when the audit event was created."""
    description: list[str]
    """A detailed description of the audit event."""
    remote_address: list[str]
    """The IP address from which the audit event originated."""
    summary: list[str]
    """A brief summary or title describing the audit event."""
    super_admin: list[bool]
    """Indicates if the user triggering the audit event is a super admin."""
    sys_admin: list[bool]
    """Indicates if the user triggering the audit event is a system admin."""


class AuditAnyValueFilter(TypedDict, total=False):
    """Available fields with Any value type. Used for 'contains' and 'any' conditions."""
    affected_object: Any
    """The object that was affected by the audit event."""
    associated_objects: Any
    """Any associated objects related to the audit event."""
    author: Any
    """The user who triggered the audit event."""
    category: Any
    """The category under which the audit event falls."""
    changed_values: Any
    """Details of the values that were changed during the audit event."""
    creation_date: Any
    """The date and time when the audit event was created."""
    description: Any
    """A detailed description of the audit event."""
    remote_address: Any
    """The IP address from which the audit event originated."""
    summary: Any
    """A brief summary or title describing the audit event."""
    super_admin: Any
    """Indicates if the user triggering the audit event is a super admin."""
    sys_admin: Any
    """Indicates if the user triggering the audit event is a system admin."""


class AuditStringFilter(TypedDict, total=False):
    """String fields for text search conditions (like, fuzzy, keyword)."""
    affected_object: str
    """The object that was affected by the audit event."""
    associated_objects: str
    """Any associated objects related to the audit event."""
    author: str
    """The user who triggered the audit event."""
    category: str
    """The category under which the audit event falls."""
    changed_values: str
    """Details of the values that were changed during the audit event."""
    creation_date: str
    """The date and time when the audit event was created."""
    description: str
    """A detailed description of the audit event."""
    remote_address: str
    """The IP address from which the audit event originated."""
    summary: str
    """A brief summary or title describing the audit event."""
    super_admin: str
    """Indicates if the user triggering the audit event is a super admin."""
    sys_admin: str
    """Indicates if the user triggering the audit event is a system admin."""


class AuditSortFilter(TypedDict, total=False):
    """Available fields for sorting audit search results."""
    affected_object: AirbyteSortOrder
    """The object that was affected by the audit event."""
    associated_objects: AirbyteSortOrder
    """Any associated objects related to the audit event."""
    author: AirbyteSortOrder
    """The user who triggered the audit event."""
    category: AirbyteSortOrder
    """The category under which the audit event falls."""
    changed_values: AirbyteSortOrder
    """Details of the values that were changed during the audit event."""
    creation_date: AirbyteSortOrder
    """The date and time when the audit event was created."""
    description: AirbyteSortOrder
    """A detailed description of the audit event."""
    remote_address: AirbyteSortOrder
    """The IP address from which the audit event originated."""
    summary: AirbyteSortOrder
    """A brief summary or title describing the audit event."""
    super_admin: AirbyteSortOrder
    """Indicates if the user triggering the audit event is a super admin."""
    sys_admin: AirbyteSortOrder
    """Indicates if the user triggering the audit event is a system admin."""


# Entity-specific condition types for audit
class AuditEqCondition(TypedDict, total=False):
    """Equal to: field equals value."""
    eq: AuditSearchFilter


class AuditNeqCondition(TypedDict, total=False):
    """Not equal to: field does not equal value."""
    neq: AuditSearchFilter


class AuditGtCondition(TypedDict, total=False):
    """Greater than: field > value."""
    gt: AuditSearchFilter


class AuditGteCondition(TypedDict, total=False):
    """Greater than or equal: field >= value."""
    gte: AuditSearchFilter


class AuditLtCondition(TypedDict, total=False):
    """Less than: field < value."""
    lt: AuditSearchFilter


class AuditLteCondition(TypedDict, total=False):
    """Less than or equal: field <= value."""
    lte: AuditSearchFilter


class AuditLikeCondition(TypedDict, total=False):
    """Partial string match with % wildcards."""
    like: AuditStringFilter


class AuditFuzzyCondition(TypedDict, total=False):
    """Ordered word text match (case-insensitive)."""
    fuzzy: AuditStringFilter


class AuditKeywordCondition(TypedDict, total=False):
    """Keyword text match (any word present)."""
    keyword: AuditStringFilter


class AuditContainsCondition(TypedDict, total=False):
    """Check if value exists in array field. Example: {"contains": {"tags": "premium"}}"""
    contains: AuditAnyValueFilter


# Reserved keyword conditions using functional TypedDict syntax
AuditInCondition = TypedDict("AuditInCondition", {"in": AuditInFilter}, total=False)
"""In list: field value is in list. Example: {"in": {"status": ["active", "pending"]}}"""

AuditNotCondition = TypedDict("AuditNotCondition", {"not": "AuditCondition"}, total=False)
"""Negates the nested condition."""

AuditAndCondition = TypedDict("AuditAndCondition", {"and": "list[AuditCondition]"}, total=False)
"""True if all nested conditions are true."""

AuditOrCondition = TypedDict("AuditOrCondition", {"or": "list[AuditCondition]"}, total=False)
"""True if any nested condition is true."""

AuditAnyCondition = TypedDict("AuditAnyCondition", {"any": AuditAnyValueFilter}, total=False)
"""Match if ANY element in array field matches nested condition. Example: {"any": {"addresses": {"eq": {"state": "CA"}}}}"""

# Union of all audit condition types
AuditCondition = (
    AuditEqCondition
    | AuditNeqCondition
    | AuditGtCondition
    | AuditGteCondition
    | AuditLtCondition
    | AuditLteCondition
    | AuditInCondition
    | AuditLikeCondition
    | AuditFuzzyCondition
    | AuditKeywordCondition
    | AuditContainsCondition
    | AuditNotCondition
    | AuditAndCondition
    | AuditOrCondition
    | AuditAnyCondition
)


class AuditSearchQuery(TypedDict, total=False):
    """Search query for audit entity."""
    filter: AuditCondition
    sort: list[AuditSortFilter]


# ===== BLOG_POSTS SEARCH TYPES =====

class BlogPostsSearchFilter(TypedDict, total=False):
    """Available fields for filtering blog_posts search queries."""
    links: dict[str, Any] | None
    """Links related to the blog post"""
    author_id: str | None
    """ID of the user who created the blog post"""
    body: dict[str, Any] | None
    """Blog post body content"""
    created_at: str | None
    """Timestamp when the blog post was created"""
    id: str | None
    """Unique blog post identifier"""
    space_id: str | None
    """ID of the space containing this blog post"""
    status: str | None
    """Blog post status (current, draft, trashed)"""
    title: str | None
    """Blog post title"""
    version: dict[str, Any] | None
    """Version information"""


class BlogPostsInFilter(TypedDict, total=False):
    """Available fields for 'in' condition (values are lists)."""
    links: list[dict[str, Any]]
    """Links related to the blog post"""
    author_id: list[str]
    """ID of the user who created the blog post"""
    body: list[dict[str, Any]]
    """Blog post body content"""
    created_at: list[str]
    """Timestamp when the blog post was created"""
    id: list[str]
    """Unique blog post identifier"""
    space_id: list[str]
    """ID of the space containing this blog post"""
    status: list[str]
    """Blog post status (current, draft, trashed)"""
    title: list[str]
    """Blog post title"""
    version: list[dict[str, Any]]
    """Version information"""


class BlogPostsAnyValueFilter(TypedDict, total=False):
    """Available fields with Any value type. Used for 'contains' and 'any' conditions."""
    links: Any
    """Links related to the blog post"""
    author_id: Any
    """ID of the user who created the blog post"""
    body: Any
    """Blog post body content"""
    created_at: Any
    """Timestamp when the blog post was created"""
    id: Any
    """Unique blog post identifier"""
    space_id: Any
    """ID of the space containing this blog post"""
    status: Any
    """Blog post status (current, draft, trashed)"""
    title: Any
    """Blog post title"""
    version: Any
    """Version information"""


class BlogPostsStringFilter(TypedDict, total=False):
    """String fields for text search conditions (like, fuzzy, keyword)."""
    links: str
    """Links related to the blog post"""
    author_id: str
    """ID of the user who created the blog post"""
    body: str
    """Blog post body content"""
    created_at: str
    """Timestamp when the blog post was created"""
    id: str
    """Unique blog post identifier"""
    space_id: str
    """ID of the space containing this blog post"""
    status: str
    """Blog post status (current, draft, trashed)"""
    title: str
    """Blog post title"""
    version: str
    """Version information"""


class BlogPostsSortFilter(TypedDict, total=False):
    """Available fields for sorting blog_posts search results."""
    links: AirbyteSortOrder
    """Links related to the blog post"""
    author_id: AirbyteSortOrder
    """ID of the user who created the blog post"""
    body: AirbyteSortOrder
    """Blog post body content"""
    created_at: AirbyteSortOrder
    """Timestamp when the blog post was created"""
    id: AirbyteSortOrder
    """Unique blog post identifier"""
    space_id: AirbyteSortOrder
    """ID of the space containing this blog post"""
    status: AirbyteSortOrder
    """Blog post status (current, draft, trashed)"""
    title: AirbyteSortOrder
    """Blog post title"""
    version: AirbyteSortOrder
    """Version information"""


# Entity-specific condition types for blog_posts
class BlogPostsEqCondition(TypedDict, total=False):
    """Equal to: field equals value."""
    eq: BlogPostsSearchFilter


class BlogPostsNeqCondition(TypedDict, total=False):
    """Not equal to: field does not equal value."""
    neq: BlogPostsSearchFilter


class BlogPostsGtCondition(TypedDict, total=False):
    """Greater than: field > value."""
    gt: BlogPostsSearchFilter


class BlogPostsGteCondition(TypedDict, total=False):
    """Greater than or equal: field >= value."""
    gte: BlogPostsSearchFilter


class BlogPostsLtCondition(TypedDict, total=False):
    """Less than: field < value."""
    lt: BlogPostsSearchFilter


class BlogPostsLteCondition(TypedDict, total=False):
    """Less than or equal: field <= value."""
    lte: BlogPostsSearchFilter


class BlogPostsLikeCondition(TypedDict, total=False):
    """Partial string match with % wildcards."""
    like: BlogPostsStringFilter


class BlogPostsFuzzyCondition(TypedDict, total=False):
    """Ordered word text match (case-insensitive)."""
    fuzzy: BlogPostsStringFilter


class BlogPostsKeywordCondition(TypedDict, total=False):
    """Keyword text match (any word present)."""
    keyword: BlogPostsStringFilter


class BlogPostsContainsCondition(TypedDict, total=False):
    """Check if value exists in array field. Example: {"contains": {"tags": "premium"}}"""
    contains: BlogPostsAnyValueFilter


# Reserved keyword conditions using functional TypedDict syntax
BlogPostsInCondition = TypedDict("BlogPostsInCondition", {"in": BlogPostsInFilter}, total=False)
"""In list: field value is in list. Example: {"in": {"status": ["active", "pending"]}}"""

BlogPostsNotCondition = TypedDict("BlogPostsNotCondition", {"not": "BlogPostsCondition"}, total=False)
"""Negates the nested condition."""

BlogPostsAndCondition = TypedDict("BlogPostsAndCondition", {"and": "list[BlogPostsCondition]"}, total=False)
"""True if all nested conditions are true."""

BlogPostsOrCondition = TypedDict("BlogPostsOrCondition", {"or": "list[BlogPostsCondition]"}, total=False)
"""True if any nested condition is true."""

BlogPostsAnyCondition = TypedDict("BlogPostsAnyCondition", {"any": BlogPostsAnyValueFilter}, total=False)
"""Match if ANY element in array field matches nested condition. Example: {"any": {"addresses": {"eq": {"state": "CA"}}}}"""

# Union of all blog_posts condition types
BlogPostsCondition = (
    BlogPostsEqCondition
    | BlogPostsNeqCondition
    | BlogPostsGtCondition
    | BlogPostsGteCondition
    | BlogPostsLtCondition
    | BlogPostsLteCondition
    | BlogPostsInCondition
    | BlogPostsLikeCondition
    | BlogPostsFuzzyCondition
    | BlogPostsKeywordCondition
    | BlogPostsContainsCondition
    | BlogPostsNotCondition
    | BlogPostsAndCondition
    | BlogPostsOrCondition
    | BlogPostsAnyCondition
)


class BlogPostsSearchQuery(TypedDict, total=False):
    """Search query for blog_posts entity."""
    filter: BlogPostsCondition
    sort: list[BlogPostsSortFilter]


# ===== GROUPS SEARCH TYPES =====

class GroupsSearchFilter(TypedDict, total=False):
    """Available fields for filtering groups search queries."""
    links: dict[str, Any] | None
    """Links related to the group"""
    id: str | None
    """The unique identifier of the group"""
    name: str | None
    """The name of the group"""
    type_: str | None
    """The type of group"""


class GroupsInFilter(TypedDict, total=False):
    """Available fields for 'in' condition (values are lists)."""
    links: list[dict[str, Any]]
    """Links related to the group"""
    id: list[str]
    """The unique identifier of the group"""
    name: list[str]
    """The name of the group"""
    type_: list[str]
    """The type of group"""


class GroupsAnyValueFilter(TypedDict, total=False):
    """Available fields with Any value type. Used for 'contains' and 'any' conditions."""
    links: Any
    """Links related to the group"""
    id: Any
    """The unique identifier of the group"""
    name: Any
    """The name of the group"""
    type_: Any
    """The type of group"""


class GroupsStringFilter(TypedDict, total=False):
    """String fields for text search conditions (like, fuzzy, keyword)."""
    links: str
    """Links related to the group"""
    id: str
    """The unique identifier of the group"""
    name: str
    """The name of the group"""
    type_: str
    """The type of group"""


class GroupsSortFilter(TypedDict, total=False):
    """Available fields for sorting groups search results."""
    links: AirbyteSortOrder
    """Links related to the group"""
    id: AirbyteSortOrder
    """The unique identifier of the group"""
    name: AirbyteSortOrder
    """The name of the group"""
    type_: AirbyteSortOrder
    """The type of group"""


# Entity-specific condition types for groups
class GroupsEqCondition(TypedDict, total=False):
    """Equal to: field equals value."""
    eq: GroupsSearchFilter


class GroupsNeqCondition(TypedDict, total=False):
    """Not equal to: field does not equal value."""
    neq: GroupsSearchFilter


class GroupsGtCondition(TypedDict, total=False):
    """Greater than: field > value."""
    gt: GroupsSearchFilter


class GroupsGteCondition(TypedDict, total=False):
    """Greater than or equal: field >= value."""
    gte: GroupsSearchFilter


class GroupsLtCondition(TypedDict, total=False):
    """Less than: field < value."""
    lt: GroupsSearchFilter


class GroupsLteCondition(TypedDict, total=False):
    """Less than or equal: field <= value."""
    lte: GroupsSearchFilter


class GroupsLikeCondition(TypedDict, total=False):
    """Partial string match with % wildcards."""
    like: GroupsStringFilter


class GroupsFuzzyCondition(TypedDict, total=False):
    """Ordered word text match (case-insensitive)."""
    fuzzy: GroupsStringFilter


class GroupsKeywordCondition(TypedDict, total=False):
    """Keyword text match (any word present)."""
    keyword: GroupsStringFilter


class GroupsContainsCondition(TypedDict, total=False):
    """Check if value exists in array field. Example: {"contains": {"tags": "premium"}}"""
    contains: GroupsAnyValueFilter


# Reserved keyword conditions using functional TypedDict syntax
GroupsInCondition = TypedDict("GroupsInCondition", {"in": GroupsInFilter}, total=False)
"""In list: field value is in list. Example: {"in": {"status": ["active", "pending"]}}"""

GroupsNotCondition = TypedDict("GroupsNotCondition", {"not": "GroupsCondition"}, total=False)
"""Negates the nested condition."""

GroupsAndCondition = TypedDict("GroupsAndCondition", {"and": "list[GroupsCondition]"}, total=False)
"""True if all nested conditions are true."""

GroupsOrCondition = TypedDict("GroupsOrCondition", {"or": "list[GroupsCondition]"}, total=False)
"""True if any nested condition is true."""

GroupsAnyCondition = TypedDict("GroupsAnyCondition", {"any": GroupsAnyValueFilter}, total=False)
"""Match if ANY element in array field matches nested condition. Example: {"any": {"addresses": {"eq": {"state": "CA"}}}}"""

# Union of all groups condition types
GroupsCondition = (
    GroupsEqCondition
    | GroupsNeqCondition
    | GroupsGtCondition
    | GroupsGteCondition
    | GroupsLtCondition
    | GroupsLteCondition
    | GroupsInCondition
    | GroupsLikeCondition
    | GroupsFuzzyCondition
    | GroupsKeywordCondition
    | GroupsContainsCondition
    | GroupsNotCondition
    | GroupsAndCondition
    | GroupsOrCondition
    | GroupsAnyCondition
)


class GroupsSearchQuery(TypedDict, total=False):
    """Search query for groups entity."""
    filter: GroupsCondition
    sort: list[GroupsSortFilter]


# ===== PAGES SEARCH TYPES =====

class PagesSearchFilter(TypedDict, total=False):
    """Available fields for filtering pages search queries."""
    links: dict[str, Any] | None
    """Links related to the page"""
    author_id: str | None
    """ID of the user who created the page"""
    body: dict[str, Any] | None
    """Page body content"""
    created_at: str | None
    """Timestamp when the page was created"""
    id: str | None
    """Unique page identifier"""
    last_owner_id: str | None
    """ID of the previous page owner"""
    owner_id: str | None
    """ID of the current page owner"""
    parent_id: str | None
    """ID of the parent page"""
    parent_type: str | None
    """Type of the parent (page or space)"""
    position: int | None
    """Position of the page among siblings"""
    space_id: str | None
    """ID of the space containing this page"""
    status: str | None
    """Page status (current, archived, trashed, draft)"""
    title: str | None
    """Page title"""
    version: dict[str, Any] | None
    """Version information"""


class PagesInFilter(TypedDict, total=False):
    """Available fields for 'in' condition (values are lists)."""
    links: list[dict[str, Any]]
    """Links related to the page"""
    author_id: list[str]
    """ID of the user who created the page"""
    body: list[dict[str, Any]]
    """Page body content"""
    created_at: list[str]
    """Timestamp when the page was created"""
    id: list[str]
    """Unique page identifier"""
    last_owner_id: list[str]
    """ID of the previous page owner"""
    owner_id: list[str]
    """ID of the current page owner"""
    parent_id: list[str]
    """ID of the parent page"""
    parent_type: list[str]
    """Type of the parent (page or space)"""
    position: list[int]
    """Position of the page among siblings"""
    space_id: list[str]
    """ID of the space containing this page"""
    status: list[str]
    """Page status (current, archived, trashed, draft)"""
    title: list[str]
    """Page title"""
    version: list[dict[str, Any]]
    """Version information"""


class PagesAnyValueFilter(TypedDict, total=False):
    """Available fields with Any value type. Used for 'contains' and 'any' conditions."""
    links: Any
    """Links related to the page"""
    author_id: Any
    """ID of the user who created the page"""
    body: Any
    """Page body content"""
    created_at: Any
    """Timestamp when the page was created"""
    id: Any
    """Unique page identifier"""
    last_owner_id: Any
    """ID of the previous page owner"""
    owner_id: Any
    """ID of the current page owner"""
    parent_id: Any
    """ID of the parent page"""
    parent_type: Any
    """Type of the parent (page or space)"""
    position: Any
    """Position of the page among siblings"""
    space_id: Any
    """ID of the space containing this page"""
    status: Any
    """Page status (current, archived, trashed, draft)"""
    title: Any
    """Page title"""
    version: Any
    """Version information"""


class PagesStringFilter(TypedDict, total=False):
    """String fields for text search conditions (like, fuzzy, keyword)."""
    links: str
    """Links related to the page"""
    author_id: str
    """ID of the user who created the page"""
    body: str
    """Page body content"""
    created_at: str
    """Timestamp when the page was created"""
    id: str
    """Unique page identifier"""
    last_owner_id: str
    """ID of the previous page owner"""
    owner_id: str
    """ID of the current page owner"""
    parent_id: str
    """ID of the parent page"""
    parent_type: str
    """Type of the parent (page or space)"""
    position: str
    """Position of the page among siblings"""
    space_id: str
    """ID of the space containing this page"""
    status: str
    """Page status (current, archived, trashed, draft)"""
    title: str
    """Page title"""
    version: str
    """Version information"""


class PagesSortFilter(TypedDict, total=False):
    """Available fields for sorting pages search results."""
    links: AirbyteSortOrder
    """Links related to the page"""
    author_id: AirbyteSortOrder
    """ID of the user who created the page"""
    body: AirbyteSortOrder
    """Page body content"""
    created_at: AirbyteSortOrder
    """Timestamp when the page was created"""
    id: AirbyteSortOrder
    """Unique page identifier"""
    last_owner_id: AirbyteSortOrder
    """ID of the previous page owner"""
    owner_id: AirbyteSortOrder
    """ID of the current page owner"""
    parent_id: AirbyteSortOrder
    """ID of the parent page"""
    parent_type: AirbyteSortOrder
    """Type of the parent (page or space)"""
    position: AirbyteSortOrder
    """Position of the page among siblings"""
    space_id: AirbyteSortOrder
    """ID of the space containing this page"""
    status: AirbyteSortOrder
    """Page status (current, archived, trashed, draft)"""
    title: AirbyteSortOrder
    """Page title"""
    version: AirbyteSortOrder
    """Version information"""


# Entity-specific condition types for pages
class PagesEqCondition(TypedDict, total=False):
    """Equal to: field equals value."""
    eq: PagesSearchFilter


class PagesNeqCondition(TypedDict, total=False):
    """Not equal to: field does not equal value."""
    neq: PagesSearchFilter


class PagesGtCondition(TypedDict, total=False):
    """Greater than: field > value."""
    gt: PagesSearchFilter


class PagesGteCondition(TypedDict, total=False):
    """Greater than or equal: field >= value."""
    gte: PagesSearchFilter


class PagesLtCondition(TypedDict, total=False):
    """Less than: field < value."""
    lt: PagesSearchFilter


class PagesLteCondition(TypedDict, total=False):
    """Less than or equal: field <= value."""
    lte: PagesSearchFilter


class PagesLikeCondition(TypedDict, total=False):
    """Partial string match with % wildcards."""
    like: PagesStringFilter


class PagesFuzzyCondition(TypedDict, total=False):
    """Ordered word text match (case-insensitive)."""
    fuzzy: PagesStringFilter


class PagesKeywordCondition(TypedDict, total=False):
    """Keyword text match (any word present)."""
    keyword: PagesStringFilter


class PagesContainsCondition(TypedDict, total=False):
    """Check if value exists in array field. Example: {"contains": {"tags": "premium"}}"""
    contains: PagesAnyValueFilter


# Reserved keyword conditions using functional TypedDict syntax
PagesInCondition = TypedDict("PagesInCondition", {"in": PagesInFilter}, total=False)
"""In list: field value is in list. Example: {"in": {"status": ["active", "pending"]}}"""

PagesNotCondition = TypedDict("PagesNotCondition", {"not": "PagesCondition"}, total=False)
"""Negates the nested condition."""

PagesAndCondition = TypedDict("PagesAndCondition", {"and": "list[PagesCondition]"}, total=False)
"""True if all nested conditions are true."""

PagesOrCondition = TypedDict("PagesOrCondition", {"or": "list[PagesCondition]"}, total=False)
"""True if any nested condition is true."""

PagesAnyCondition = TypedDict("PagesAnyCondition", {"any": PagesAnyValueFilter}, total=False)
"""Match if ANY element in array field matches nested condition. Example: {"any": {"addresses": {"eq": {"state": "CA"}}}}"""

# Union of all pages condition types
PagesCondition = (
    PagesEqCondition
    | PagesNeqCondition
    | PagesGtCondition
    | PagesGteCondition
    | PagesLtCondition
    | PagesLteCondition
    | PagesInCondition
    | PagesLikeCondition
    | PagesFuzzyCondition
    | PagesKeywordCondition
    | PagesContainsCondition
    | PagesNotCondition
    | PagesAndCondition
    | PagesOrCondition
    | PagesAnyCondition
)


class PagesSearchQuery(TypedDict, total=False):
    """Search query for pages entity."""
    filter: PagesCondition
    sort: list[PagesSortFilter]


# ===== SPACES SEARCH TYPES =====

class SpacesSearchFilter(TypedDict, total=False):
    """Available fields for filtering spaces search queries."""
    links: dict[str, Any] | None
    """Links related to the space"""
    author_id: str | None
    """ID of the user who created the space"""
    created_at: str | None
    """Timestamp when the space was created"""
    description: dict[str, Any] | None
    """Space description in various formats"""
    homepage_id: str | None
    """ID of the space homepage"""
    icon: dict[str, Any] | None
    """Space icon information"""
    id: str | None
    """Unique space identifier"""
    key: str | None
    """Space key"""
    name: str | None
    """Space name"""
    status: str | None
    """Space status (current or archived)"""
    type_: str | None
    """Space type (global or personal)"""


class SpacesInFilter(TypedDict, total=False):
    """Available fields for 'in' condition (values are lists)."""
    links: list[dict[str, Any]]
    """Links related to the space"""
    author_id: list[str]
    """ID of the user who created the space"""
    created_at: list[str]
    """Timestamp when the space was created"""
    description: list[dict[str, Any]]
    """Space description in various formats"""
    homepage_id: list[str]
    """ID of the space homepage"""
    icon: list[dict[str, Any]]
    """Space icon information"""
    id: list[str]
    """Unique space identifier"""
    key: list[str]
    """Space key"""
    name: list[str]
    """Space name"""
    status: list[str]
    """Space status (current or archived)"""
    type_: list[str]
    """Space type (global or personal)"""


class SpacesAnyValueFilter(TypedDict, total=False):
    """Available fields with Any value type. Used for 'contains' and 'any' conditions."""
    links: Any
    """Links related to the space"""
    author_id: Any
    """ID of the user who created the space"""
    created_at: Any
    """Timestamp when the space was created"""
    description: Any
    """Space description in various formats"""
    homepage_id: Any
    """ID of the space homepage"""
    icon: Any
    """Space icon information"""
    id: Any
    """Unique space identifier"""
    key: Any
    """Space key"""
    name: Any
    """Space name"""
    status: Any
    """Space status (current or archived)"""
    type_: Any
    """Space type (global or personal)"""


class SpacesStringFilter(TypedDict, total=False):
    """String fields for text search conditions (like, fuzzy, keyword)."""
    links: str
    """Links related to the space"""
    author_id: str
    """ID of the user who created the space"""
    created_at: str
    """Timestamp when the space was created"""
    description: str
    """Space description in various formats"""
    homepage_id: str
    """ID of the space homepage"""
    icon: str
    """Space icon information"""
    id: str
    """Unique space identifier"""
    key: str
    """Space key"""
    name: str
    """Space name"""
    status: str
    """Space status (current or archived)"""
    type_: str
    """Space type (global or personal)"""


class SpacesSortFilter(TypedDict, total=False):
    """Available fields for sorting spaces search results."""
    links: AirbyteSortOrder
    """Links related to the space"""
    author_id: AirbyteSortOrder
    """ID of the user who created the space"""
    created_at: AirbyteSortOrder
    """Timestamp when the space was created"""
    description: AirbyteSortOrder
    """Space description in various formats"""
    homepage_id: AirbyteSortOrder
    """ID of the space homepage"""
    icon: AirbyteSortOrder
    """Space icon information"""
    id: AirbyteSortOrder
    """Unique space identifier"""
    key: AirbyteSortOrder
    """Space key"""
    name: AirbyteSortOrder
    """Space name"""
    status: AirbyteSortOrder
    """Space status (current or archived)"""
    type_: AirbyteSortOrder
    """Space type (global or personal)"""


# Entity-specific condition types for spaces
class SpacesEqCondition(TypedDict, total=False):
    """Equal to: field equals value."""
    eq: SpacesSearchFilter


class SpacesNeqCondition(TypedDict, total=False):
    """Not equal to: field does not equal value."""
    neq: SpacesSearchFilter


class SpacesGtCondition(TypedDict, total=False):
    """Greater than: field > value."""
    gt: SpacesSearchFilter


class SpacesGteCondition(TypedDict, total=False):
    """Greater than or equal: field >= value."""
    gte: SpacesSearchFilter


class SpacesLtCondition(TypedDict, total=False):
    """Less than: field < value."""
    lt: SpacesSearchFilter


class SpacesLteCondition(TypedDict, total=False):
    """Less than or equal: field <= value."""
    lte: SpacesSearchFilter


class SpacesLikeCondition(TypedDict, total=False):
    """Partial string match with % wildcards."""
    like: SpacesStringFilter


class SpacesFuzzyCondition(TypedDict, total=False):
    """Ordered word text match (case-insensitive)."""
    fuzzy: SpacesStringFilter


class SpacesKeywordCondition(TypedDict, total=False):
    """Keyword text match (any word present)."""
    keyword: SpacesStringFilter


class SpacesContainsCondition(TypedDict, total=False):
    """Check if value exists in array field. Example: {"contains": {"tags": "premium"}}"""
    contains: SpacesAnyValueFilter


# Reserved keyword conditions using functional TypedDict syntax
SpacesInCondition = TypedDict("SpacesInCondition", {"in": SpacesInFilter}, total=False)
"""In list: field value is in list. Example: {"in": {"status": ["active", "pending"]}}"""

SpacesNotCondition = TypedDict("SpacesNotCondition", {"not": "SpacesCondition"}, total=False)
"""Negates the nested condition."""

SpacesAndCondition = TypedDict("SpacesAndCondition", {"and": "list[SpacesCondition]"}, total=False)
"""True if all nested conditions are true."""

SpacesOrCondition = TypedDict("SpacesOrCondition", {"or": "list[SpacesCondition]"}, total=False)
"""True if any nested condition is true."""

SpacesAnyCondition = TypedDict("SpacesAnyCondition", {"any": SpacesAnyValueFilter}, total=False)
"""Match if ANY element in array field matches nested condition. Example: {"any": {"addresses": {"eq": {"state": "CA"}}}}"""

# Union of all spaces condition types
SpacesCondition = (
    SpacesEqCondition
    | SpacesNeqCondition
    | SpacesGtCondition
    | SpacesGteCondition
    | SpacesLtCondition
    | SpacesLteCondition
    | SpacesInCondition
    | SpacesLikeCondition
    | SpacesFuzzyCondition
    | SpacesKeywordCondition
    | SpacesContainsCondition
    | SpacesNotCondition
    | SpacesAndCondition
    | SpacesOrCondition
    | SpacesAnyCondition
)


class SpacesSearchQuery(TypedDict, total=False):
    """Search query for spaces entity."""
    filter: SpacesCondition
    sort: list[SpacesSortFilter]



# ===== SEARCH PARAMS =====

class AirbyteSearchParams(TypedDict, total=False):
    """Parameters for Airbyte cache search operations (generic, use entity-specific query types for better type hints)."""
    query: dict[str, Any]
    limit: int
    cursor: str
    fields: list[list[str]]



"""
Blessed Confluence connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import ConfluenceConnector
from .models import (
    ConfluenceAuthConfig,
    SpaceLinks,
    Space,
    SpacesListLinks,
    SpacesList,
    PageBody,
    PageVersion,
    PageLinks,
    Page,
    PagesListLinks,
    PagesList,
    BlogPostLinks,
    BlogPostVersion,
    BlogPostBody,
    BlogPost,
    BlogPostsListLinks,
    BlogPostsList,
    GroupLinks,
    Group,
    GroupsListLinks,
    GroupsList,
    AuditRecordAffectedobject,
    AuditRecordAssociatedobjectsItem,
    AuditRecordAuthor,
    AuditRecord,
    AuditRecordsListLinks,
    AuditRecordsList,
    SpacesListResultMeta,
    PagesListResultMeta,
    BlogPostsListResultMeta,
    GroupsListResultMeta,
    AuditListResultMeta,
    ConfluenceCheckResult,
    ConfluenceExecuteResult,
    ConfluenceExecuteResultWithMeta,
    SpacesListResult,
    PagesListResult,
    BlogPostsListResult,
    GroupsListResult,
    AuditListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    AuditSearchData,
    AuditSearchResult,
    BlogPostsSearchData,
    BlogPostsSearchResult,
    GroupsSearchData,
    GroupsSearchResult,
    PagesSearchData,
    PagesSearchResult,
    SpacesSearchData,
    SpacesSearchResult
)
from .types import (
    SpacesListParams,
    SpacesGetParams,
    PagesListParams,
    PagesGetParams,
    BlogPostsListParams,
    BlogPostsGetParams,
    GroupsListParams,
    AuditListParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    AuditSearchFilter,
    AuditSearchQuery,
    AuditCondition,
    BlogPostsSearchFilter,
    BlogPostsSearchQuery,
    BlogPostsCondition,
    GroupsSearchFilter,
    GroupsSearchQuery,
    GroupsCondition,
    PagesSearchFilter,
    PagesSearchQuery,
    PagesCondition,
    SpacesSearchFilter,
    SpacesSearchQuery,
    SpacesCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "ConfluenceConnector",
    "AirbyteAuthConfig",
    "ConfluenceAuthConfig",
    "SpaceLinks",
    "Space",
    "SpacesListLinks",
    "SpacesList",
    "PageBody",
    "PageVersion",
    "PageLinks",
    "Page",
    "PagesListLinks",
    "PagesList",
    "BlogPostLinks",
    "BlogPostVersion",
    "BlogPostBody",
    "BlogPost",
    "BlogPostsListLinks",
    "BlogPostsList",
    "GroupLinks",
    "Group",
    "GroupsListLinks",
    "GroupsList",
    "AuditRecordAffectedobject",
    "AuditRecordAssociatedobjectsItem",
    "AuditRecordAuthor",
    "AuditRecord",
    "AuditRecordsListLinks",
    "AuditRecordsList",
    "SpacesListResultMeta",
    "PagesListResultMeta",
    "BlogPostsListResultMeta",
    "GroupsListResultMeta",
    "AuditListResultMeta",
    "ConfluenceCheckResult",
    "ConfluenceExecuteResult",
    "ConfluenceExecuteResultWithMeta",
    "SpacesListResult",
    "PagesListResult",
    "BlogPostsListResult",
    "GroupsListResult",
    "AuditListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "AuditSearchData",
    "AuditSearchResult",
    "BlogPostsSearchData",
    "BlogPostsSearchResult",
    "GroupsSearchData",
    "GroupsSearchResult",
    "PagesSearchData",
    "PagesSearchResult",
    "SpacesSearchData",
    "SpacesSearchResult",
    "SpacesListParams",
    "SpacesGetParams",
    "PagesListParams",
    "PagesGetParams",
    "BlogPostsListParams",
    "BlogPostsGetParams",
    "GroupsListParams",
    "AuditListParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "AuditSearchFilter",
    "AuditSearchQuery",
    "AuditCondition",
    "BlogPostsSearchFilter",
    "BlogPostsSearchQuery",
    "BlogPostsCondition",
    "GroupsSearchFilter",
    "GroupsSearchQuery",
    "GroupsCondition",
    "PagesSearchFilter",
    "PagesSearchQuery",
    "PagesCondition",
    "SpacesSearchFilter",
    "SpacesSearchQuery",
    "SpacesCondition",
]